@@ -1,23 +1,33 @@
 """Strategy class for workbook/xlsx."""
 # pylint: disable=unused-argument
 from dataclasses import dataclass
-from typing import TYPE_CHECKING, List, Optional, Union
+from typing import TYPE_CHECKING, Dict, List, Optional, Union
 
 from openpyxl import load_workbook
 from openpyxl.utils import column_index_from_string, get_column_letter
-from pydantic import BaseModel, Extra, Field
+from pydantic import BaseModel, Field
 
 from oteapi.datacache import DataCache
+from oteapi.models import AttrDict, SessionUpdate
 from oteapi.plugins import create_strategy
 
 if TYPE_CHECKING:  # pragma: no cover
-    from typing import Any, Dict, Iterable
+    from typing import Any, Iterable
 
     from openpyxl.worksheet.worksheet import Worksheet
 
     from oteapi.models import ResourceConfig
 
 
+class SessionUpdateXLSXParse(SessionUpdate):
+    """Class for returning values from XLSXParse."""
+
+    data: Dict[str, list] = Field(
+        ...,
+        description="A dict with column-name/column-value pairs. The values are lists.",
+    )
+
+
 class XLSXParseDataModel(BaseModel):
     """Data model for retrieving a rectangular section of an Excel sheet."""
 
@@ -63,6 +73,10 @@ class XLSXParseDataModel(BaseModel):
             "Optional list of new column names replacing `header` in the output."
         ),
     )
+    download_config: AttrDict = Field(
+        AttrDict(),
+        description="Configurations provided to a download strategy.",
+    )
 
 
 def set_model_defaults(model: XLSXParseDataModel, worksheet: "Worksheet") -> None:
@@ -134,28 +148,28 @@ class XLSXParseStrategy:
 
     parse_config: "ResourceConfig"
 
-    def initialize(
-        self, session: "Optional[Dict[str, Any]]" = None
-    ) -> "Dict[str, Any]":
+    def initialize(self, session: "Optional[Dict[str, Any]]" = None) -> SessionUpdate:
         """Initialize."""
-        return {}
+        return SessionUpdate()
 
-    def get(self, session: "Optional[Dict[str, Any]]" = None) -> "Dict[str, Any]":
+    def get(self, session: "Optional[Dict[str, Any]]" = None) -> SessionUpdateXLSXParse:
         """Parses selected region of an excel file.
 
         Returns:
             A dict with column-name/column-value pairs. The values are lists.
 
         """
-        model = XLSXParseDataModel(
-            **self.parse_config.configuration, extra=Extra.ignore
-        )
+        model = XLSXParseDataModel(**self.parse_config.configuration)
 
-        downloader = create_strategy("download", self.parse_config)
+        download_config = self.parse_config.copy()
+        download_config.configuration = model.download_config
+        downloader = create_strategy("download", download_config)
         output = downloader.get()
+
         cache = DataCache(self.parse_config.configuration)
         with cache.getfile(key=output["key"], suffix=".xlsx") as filename:
             workbook = load_workbook(filename=filename, read_only=True, data_only=True)
+
         worksheet = workbook[model.worksheet]
         set_model_defaults(model, worksheet)
         columns = get_column_indices(model, worksheet)
@@ -197,5 +211,7 @@ class XLSXParseStrategy:
         if header is None:
             header = [get_column_letter(col + 1) for col in range(len(data))]
 
-        transposed = list(map(list, zip(*data)))
-        return {k: v for k, v in zip(header, transposed)}
+        transposed = [list(datum) for datum in zip(*data)]
+        return SessionUpdateXLSXParse(
+            data={key: value for key, value in zip(header, transposed)}
+        )
